package com.ruoyi.model.service;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.model.domain.AppletAmountLog;

/**
 * 金额明细Service接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface IAppletAmountLogService extends IService<AppletAmountLog>
{
    /**
     * 查询金额明细
     * 
     * @param id 金额明细主键
     * @return 金额明细
     */
    public AppletAmountLog selectAppletAmountLogById(Long id);

    /**
     * 查询金额明细列表
     * 
     * @param appletAmountLog 金额明细
     * @return 金额明细集合
     */
    public List<AppletAmountLog> selectAppletAmountLogList(AppletAmountLog appletAmountLog);

    /**
     * 新增金额明细
     * 
     * @param appletAmountLog 金额明细
     * @return 结果
     */
    public int insertAppletAmountLog(AppletAmountLog appletAmountLog);

    /**
     * 修改金额明细
     * 
     * @param appletAmountLog 金额明细
     * @return 结果
     */
    public int updateAppletAmountLog(AppletAmountLog appletAmountLog);

    /**
     * 批量删除金额明细
     * 
     * @param ids 需要删除的金额明细主键集合
     * @return 结果
     */
    public int deleteAppletAmountLogByIds(Long[] ids);

    /**
     * 删除金额明细信息
     * 
     * @param id 金额明细主键
     * @return 结果
     */
    public int deleteAppletAmountLogById(Long id);
}
